==> osb-nrcit-0.5.0.tar.gz: osb-nrcit-0.5.0/src/HttpCurl.h <==
/*
 * Copyright (c) 2004 Nokia. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the
 * distribution.
 *
 * Neither the name of Nokia nor the names of its contributors may be
 * used to endorse or promote products derived from this software
 * without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef KWIQHttpCurl_h
#define KWIQHttpCurl_h

#include "Http.h"

#include <unistd.h>
#include <glib.h>
#include <curl/curl.h>

class CurlRequest;

class CurlFactoryS : public HttpFactoryS
{
    CurlFactoryS();
public:
    ~CurlFactoryS();

    HttpRequest* createRequest(HttpRequestListener* listener,
                               OSB::URLCredentialStorage* credentials,
			       const gchar * url,
			       HttpRequest::Type type);

    void setProxy(const gchar * proto, const gchar * proxyURL);

    bool canProvide(const gchar * url) const;
    gboolean event();    
 private:
    void update();
    void clearPolls();
    
    CURLM* curlMultiHandle;

    /** curl filehandles to poll with select */
    fd_set fdread;
    fd_set fdwrite;
    fd_set fdexcep;
    int maxfd;
    
    /** select callback timeout interval in milliseconds */
    static const int callbackTimeoutMS = 100;
    
    /** select timeout in milliseconds */
    static const int selectTimeoutMS = 1;
    
    /** select callback timeout GSource id */
    guint gsId; 
    
    /** NULL terminated list of supported protocols.  */
    const char** curl_protocols; //not freed 
    
    /** proxy if one is set*/
    gchar * proxy;
        
    friend CurlFactoryS& CurlFactory();
};

CurlFactoryS& CurlFactory();

#endif

==> osb-nrcit_0.5.1-1.tar.gz: osb-nrcit-0.5.1/src/HttpCurl.h <==
/*
 * Copyright (c) 2004 Nokia. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the
 * distribution.
 *
 * Neither the name of Nokia nor the names of its contributors may be
 * used to endorse or promote products derived from this software
 * without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef KWIQHttpCurl_h
#define KWIQHttpCurl_h

#include "Http.h"

#include <unistd.h>
#include <glib.h>
#include <curl/curl.h>

class CurlRequest;

class CurlFactory : public HttpFactory
{
  
public:
    CurlFactory();
    ~CurlFactory();

    HttpRequest* createRequest(HttpRequestListener* listener,
                               OSB::URLCredentialStorage* credentials,
							   const gchar * url,
							   const gchar * cookies,
							   HttpRequest::Method aMethod);

    HttpRequest* createSynchronizedRequest(HttpRequestListener* listener,
										   OSB::URLCredentialStorage* credentials,
										   const gchar * url,
										   const gchar * cookies,
										   HttpRequest::Method aMethod);

    void setProxy(const gchar * proto, const gchar * proxyURL);

    bool canProvide(const gchar * url) const;
    gboolean event();
    
 private:

	// no copy semantics
	CurlFactory(const CurlFactory&);
	CurlFactory& operator=(const CurlFactory&);

    void update();
    void clearPolls();
    
    CURLM* curlMultiHandle;

    /** curl filehandles to poll with select */
    fd_set fdread;
    fd_set fdwrite;
    fd_set fdexcep;
    int maxfd;
    
    /** select callback timeout interval in milliseconds */
    static const int callbackTimeoutMS = 100;
    
    /** select timeout in milliseconds */
    static const int selectTimeoutMS = 1;
    
    /** select callback timeout GSource id */
    guint gsId; 
    
    /** NULL terminated list of supported protocols.  */
    const char* const* curl_protocols; // not freed 
    
    /** proxy if one is set*/
    gchar * proxy;       

};

#endif
